//
//  TVOCancelledCallInvite.h
//  TwilioVoice
//
//  Copyright © 2018 Twilio, Inc. All rights reserved.
//

#import <Foundation/Foundation.h>

/**
 * The `TVOCancelledCallInvite` object represents a cancelled incoming Call Invite. `TVOCancelledCallInvite`s are not created directly;
 * they are returned by the `<[TVONotificationDelegate cancelledCallInviteReceived:]>` delegate method.
 */
@interface TVOCancelledCallInvite : NSObject

/**
 * @name Properties
 */

/**
 * @brief `From` value of the Call Invite.
 */
@property (nonatomic, copy, readonly, nonnull) NSString *from;

/**
 * @brief `To` value of the Call Invite.
 */
@property (nonatomic, copy, readonly, nonnull) NSString *to;

/**
 * @brief A server assigned identifier (SID) for the incoming Call.
 */
@property (nonatomic, copy, readonly, nonnull) NSString *callSid;

/**
 * @brief `TVOCancelCallInvite` cannot be instantiated directly. See `<TVONotificationDelegate>` instead.
 *
 * @see TVONotificationDelegate
 */
- (null_unspecified instancetype)init __attribute__((unavailable("`TVOCancelledCallInvites` cannot be instantiated directly. See `TVONotificationDelegate`")));

@end
