#!/bin/bash -e

source `dirname $0`/env.sh

MVN_ARTIFACTS_DIR=target
TWILIO_VOICE_CPP=twilio-voice

FRAMEWORK_ARCHS="x86_64 i386 armv7 arm64"
CONFIGS="release debug"

function merge_twilio_boringssl_archs() {
  mkdir -p ${MVN_ARTIFACTS_DIR}/${TWILIO_BORINGSSL}
  CONFIG="release"
  for lib in `find ${MVN_ARTIFACTS_DIR}/${ARTIFACT_PLATFORM}/${TWILIO_VOICE_CPP} -path \*${CONFIG}\* -type f -name libboringssl.a`; do
    lipo -create -output ${MVN_ARTIFACTS_DIR}/${TWILIO_BORINGSSL}/libboringssl.a `find ${MVN_ARTIFACTS_DIR}/ios/${TWILIO_VOICE_CPP} -name libboringssl.a -path \*${CONFIG}\*`
  done
}

function build_excludes() {
  for ARCH in ${FRAMEWORK_ARCHS}; do
    for CONFIG in ${CONFIGS}; do
      EXCLUSIONS_FILE=${MVN_ARTIFACTS_DIR}/unexport-${CONFIG}-${ARCH}.txt
      find ${MVN_ARTIFACTS_DIR} -path \*${ARCH}\*\*${CONFIG}\* -type f -name \*a -exec bash -c "nm -g -arch ${ARCH} {} | grep ' _' | grep -v ' U _' | sed 's/^.* _/_/' >> ${EXCLUSIONS_FILE}" \;
    done
  done
}

QUIET=""

if [ "${TRAVIS}" = "true" ]; then
  QUIET="-B"
fi

pushd `dirname ${BASH_SOURCE[0]}`/..
  BASE_DIR="$(pwd)"
popd

pushd ${BASE_DIR}
  mvn clean

  #Call maven to populate target directory with TwilioVideo.framework's dependencies
  mvn ${QUIET} -U -C -Dbuild.platform=ios || exit 1

  # Combine architectures of BoringSSL for the static library package
  merge_twilio_boringssl_archs

  build_excludes
popd